@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: first.c,v 1.32 1998/12/09 11:38:40 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -45,6 +45,7 @@ main (int argc, char *argv [])
 	unsigned c, method, count, port, i, *ptr;
 	char buffer [BUFSIZ];
 	pid_t pid, ppid;
+	char *args;
 
 	count = PROFILE_COUNT;
 
@@ -172,10 +173,22 @@ main (int argc, char *argv [])
 
 	printf ("\n");
 
+	for (c = 0; c < PROFILE_COUNT; c++)
+		glibtop_get_ppp (&data.ppp, 0);
+
+	printf ("PPP          (0x%08lx): %lu, %lu, %lu\n",
+		(unsigned long) data.ppp.flags,
+		(unsigned long) data.ppp.state,
+		(unsigned long) data.ppp.bytes_in,
+		(unsigned long) data.ppp.bytes_out);
+
+	printf ("\n");
+
 	glibtop_get_sysdeps (&sysdeps);
 
 	printf ("Sysdeps      (0x%08lx): %lu, %lu, %lu, %lu, %lu, "
-		"%lu, %lu, %lu, %lu, %lu, %lu, %lu, %lu, %lu, %lu, %lu\n",
+		"%lu, %lu, %lu, %lu, %lu, %lu, %lu, %lu, %lu, %lu, %lu, "
+		"%lu, %lu, %lu, %lu, %lu, %lu\n",
 		(unsigned long) sysdeps.flags,
 		(unsigned long) sysdeps.cpu,
 		(unsigned long) sysdeps.mem,
@@ -192,7 +205,13 @@ main (int argc, char *argv [])
 		(unsigned long) sysdeps.proc_time,
 		(unsigned long) sysdeps.proc_signal,
 		(unsigned long) sysdeps.proc_kernel,
-		(unsigned long) sysdeps.proc_segment);
+		(unsigned long) sysdeps.proc_segment,
+		(unsigned long) sysdeps.proc_args,
+		(unsigned long) sysdeps.proc_map,
+		(unsigned long) sysdeps.mountlist,
+		(unsigned long) sysdeps.fsusage,
+		(unsigned long) sysdeps.netload,
+		(unsigned long) sysdeps.ppp);
 
 	printf ("\n");
 	
@@ -313,6 +332,22 @@ main (int argc, char *argv [])
 
 	printf ("\n");
 
+	args = glibtop_get_proc_args (&data.proc_args, pid, 0);
+
+	for (i = 0; i < data.proc_args.size; i++) {
+		if (args [i]) continue;
+		args [i] = '|';
+	}
+
+	printf ("Proc_Args    PID  %5d (0x%08lx): %lu - '%s'\n", (int) pid,
+		(unsigned long) data.proc_args.flags,
+		(unsigned long) data.proc_args.size,
+		args);
+
+	glibtop_free (args);
+
+	printf ("\n");
+
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_state (&data.proc_state, ppid);
 
@@ -407,6 +442,22 @@ main (int argc, char *argv [])
 
 	printf ("\n");
 
+	args = glibtop_get_proc_args (&data.proc_args, ppid, 0);
+
+	for (i = 0; i < data.proc_args.size; i++) {
+		if (args [i]) continue;
+		args [i] = '|';
+	}
+
+	printf ("Proc_Args    PID  %5d (0x%08lx): %lu - '%s'\n", (int) ppid,
+		(unsigned long) data.proc_args.flags,
+		(unsigned long) data.proc_args.size,
+		args);
+
+	glibtop_free (args);
+
+	printf ("\n");
+
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_state (&data.proc_state, 1);
 
@@ -500,6 +551,22 @@ main (int argc, char *argv [])
 		(unsigned long) data.proc_kernel.nwchan,
 		data.proc_kernel.wchan);
 
+	printf ("\n");
+
+	args = glibtop_get_proc_args (&data.proc_args, 1, 0);
+
+	for (i = 0; i < data.proc_args.size; i++) {
+		if (args [i]) continue;
+		args [i] = '|';
+	}
+
+	printf ("Proc_Args    PID  %5d (0x%08lx): %lu - '%s'\n", 1,
+		(unsigned long) data.proc_args.flags,
+		(unsigned long) data.proc_args.size,
+		args);
+
+	glibtop_free (args);
+
 	glibtop_close ();
 
 	exit (0);
