@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: command.h,v 1.17 1998/10/26 10:38:44 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -48,12 +48,15 @@ __BEGIN_DECLS
 #define GLIBTOP_CMND_PROC_SIGNAL	15
 #define GLIBTOP_CMND_PROC_KERNEL	16
 #define GLIBTOP_CMND_PROC_SEGMENT	17
-#define GLIBTOP_CMND_PROC_MAP		18
+#define GLIBTOP_CMND_PROC_ARGS		18
+#define GLIBTOP_CMND_PROC_MAP		19
 
-#define GLIBTOP_CMND_MOUNTLIST		19
-#define GLIBTOP_CMND_FSUSAGE		20
+#define GLIBTOP_CMND_MOUNTLIST		20
+#define GLIBTOP_CMND_FSUSAGE		21
+#define GLIBTOP_CMND_NETLOAD		22
+#define GLIBTOP_CMND_PPP		23
 
-#define GLIBTOP_MAX_CMND		21
+#define GLIBTOP_MAX_CMND		24
 
 #define _GLIBTOP_PARAM_SIZE		16
 
