@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: msg_limits.h,v 1.9 1998/10/11 18:14:02 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -69,25 +69,6 @@ extern void glibtop_init_msg_limits_s __P((glibtop *));
 extern void glibtop_get_msg_limits_s __P((glibtop *, glibtop_msg_limits *));
 #endif
 
-#ifdef GLIBTOP_GUILE
-
-/* You need to link with -lgtop_guile to get this stuff here. */
-
-extern SCM glibtop_guile_get_msg_limits __P((void));
-
-#endif
-
-#ifdef GLIBTOP_GUILE_NAMES
-
-/* You need to link with -lgtop_guile_names to get this stuff here. */
-
-extern SCM glibtop_guile_names_msg_limits __P((void));
-extern SCM glibtop_guile_types_msg_limits __P((void));
-extern SCM glibtop_guile_labels_msg_limits __P((void));
-extern SCM glibtop_guile_descriptions_msg_limits __P((void));
-
-#endif
-
 #ifdef GLIBTOP_NAMES
 
 /* You need to link with -lgtop_names to get this stuff here. */
