@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: daemon.h,v 1.3 1998/12/09 21:28:43 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -33,6 +33,9 @@
 #include <glibtop/parameter.h>
 
 #include <fcntl.h>
+#include <sys/wait.h>
+#include <sys/socket.h>
+#include <syslog.h>
 
 __BEGIN_DECLS
 
@@ -57,6 +60,12 @@ extern void handle_slave_command __P((glibtop_command *, glibtop_response *, con
 extern void do_output __P((int, glibtop_response *, off_t, size_t, const void *));
 extern int do_read __P((int, void *, size_t));
 
+extern void syslog_message __P((int, char *, ...));
+extern void syslog_io_message __P((int, char *, ...));
+
+extern int enable_debug;
+extern int verbose_output;
+
 __END_DECLS
 
 #endif
