@@ -1,4 +1,4 @@
-/* $Id: prockernel.c,v 1.8 1998/08/24 19:55:26 martin Exp $ */
+/* $Id: prockernel.c,v 1.15 1998/12/06 13:02:02 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -29,9 +29,13 @@
 #include <sys/param.h>
 #include <sys/sysctl.h>
 #include <sys/proc.h>
+#ifndef __OpenBSD__
 #include <sys/user.h>
+#endif
 #include <machine/pcb.h>
+#ifdef __FreeBSD__
 #include <machine/tss.h>
+#endif
 
 #include <unistd.h>
 #include <fcntl.h>
@@ -69,19 +73,38 @@ glibtop_get_proc_kernel_p (glibtop *server,
 	struct user *u_addr = (struct user *)USRSTACK;
 	struct pstats pstats;
 	struct pcb pcb;
-	int f, count;
+	int count;
+
+	char filename [BUFSIZ];
+	struct stat statb;
 
 	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_KERNEL), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_kernel));
 
-	glibtop_suid_enter (server);
+	if (server->sysdeps.proc_time == 0)
+		return;
 
+	/* It does not work for the swapper task. */
+	if (pid == 0) return;
+	
 	/* Get the process information */
 	pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, &count);
 	if ((pinfo == NULL) || (count != 1))
 		glibtop_error_io_r (server, "kvm_getprocs (%d)", pid);
 
+	buf->nwchan = (unsigned long) pinfo [0].kp_proc.p_wchan &~ KERNBASE;
+	buf->flags |= (1 << GLIBTOP_PROC_KERNEL_NWCHAN);
+
+	if (pinfo [0].kp_proc.p_wchan && pinfo [0].kp_proc.p_wmesg) {
+		strncpy (buf->wchan, pinfo [0].kp_eproc.e_wmesg,
+			 sizeof (buf->wchan) - 1);
+		buf->wchan [sizeof (buf->wchan) - 1] = 0;
+		buf->flags |= (1 << GLIBTOP_PROC_KERNEL_WCHAN);
+	} else {
+		buf->wchan [0] = 0;
+	}
+
 	/* Taken from `saveuser ()' in `/usr/src/bin/ps/ps.c'. */
 
 	/* [FIXME]: /usr/include/sys/user.h tells me that the user area
@@ -92,7 +115,12 @@ glibtop_get_proc_kernel_p (glibtop *server,
 
 	/* NOTE: You need to mount the /proc filesystem to make
 	 *       `kvm_uread' work. */
-	
+
+	sprintf (filename, "/proc/%d/mem", pid);
+	if (stat (filename, &statb)) return;
+
+	glibtop_suid_enter (server);
+
 	if ((pinfo [0].kp_proc.p_flag & P_INMEM) &&
 	    kvm_uread (server->machine.kd, &(pinfo [0]).kp_proc,
 		       (unsigned long) &u_addr->u_stats,
@@ -118,27 +146,26 @@ glibtop_get_proc_kernel_p (glibtop *server,
 		       (unsigned long) &u_addr->u_pcb,
 		       (char *) &pcb, sizeof (pcb)) == sizeof (pcb))
 		{
-			/* Same like with pstats above. */
-			
+#if (defined __FreeBSD__) && (__FreeBSD_version >= 300000)
+
+			/* Sorry, don't know how to get it for
+			 * FreeBSD 3.0 at the moment.
+			 */
+
+#elif (defined __FreeBSD__)
 			buf->kstk_esp = (u_int64_t) pcb.pcb_ksp;
 			buf->kstk_eip = (u_int64_t) pcb.pcb_pc;
 			
 			buf->flags |= _glibtop_sysdeps_proc_kernel_pcb;
+#else
+			buf->kstk_esp = (u_int64_t) pcb.pcb_tss.tss_esp0;
+			buf->kstk_eip = (u_int64_t) pcb.pcb_tss.__tss_eip;
+
+			buf->flags |= _glibtop_sysdeps_proc_kernel_pcb;
+#endif
 		}
 
 	/* Taken from `wchan ()' in `/usr/src/bin/ps/print.c'. */
 
 	glibtop_suid_leave (server);
-
-	buf->nwchan = (unsigned long) pinfo [0].kp_proc.p_wchan &~ KERNBASE;
-
-	if (pinfo [0].kp_proc.p_wchan && pinfo [0].kp_proc.p_wmesg) {
-		strncpy (buf->wchan, pinfo [0].kp_eproc.e_wmesg,
-			 sizeof (buf->wchan) - 1);
-		buf->wchan [sizeof (buf->wchan) - 1] = 0;
-	} else {
-		buf->wchan [0] = 0;
-	}
-	
-	buf->flags |= _glibtop_sysdeps_proc_kernel_wchan;
 }
