@@ -1,4 +1,4 @@
-/* $Id: procmap.c,v 1.2 1998/08/18 16:34:24 martin Exp $ */
+/* $Id: procmap.c,v 1.6 1998/12/06 11:08:10 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -40,7 +40,9 @@
 #include <ufs/ufs/inode.h>
 
 #include <sys/ucred.h>
+#ifndef __OpenBSD__
 #include <sys/user.h>
+#endif
 #include <sys/sysctl.h>
 #include <vm/vm.h>
 
@@ -58,8 +60,6 @@ static const unsigned long _glibtop_sysdeps_map_entry =
 void
 glibtop_init_proc_map_p (glibtop *server)
 {
-	register int pagesize;
-
 	server->sysdeps.proc_map = _glibtop_sysdeps_proc_map;
 }
 
@@ -71,7 +71,7 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 {
 	struct kinfo_proc *pinfo;
 	struct vm_map_entry entry, *first;
-	struct vmspace *vms, vmspace;
+	struct vmspace vmspace;
 	struct vm_object object;
 	glibtop_map_entry *maps;
 	struct vnode vnode;
@@ -80,12 +80,19 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 	int count, i = 0;
 	int update = 0;
 
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_MAP), 0);
+	
+	memset (buf, 0, sizeof (glibtop_proc_map));
+
+	/* It does not work for the swapper task. */
+	if (pid == 0) return NULL;
+	
 	glibtop_suid_enter (server);
 
 	/* Get the process data */
 	pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, &count);
 	if ((pinfo == NULL) || (count < 1))
-		glibtop_error_io_r (server, "kvm_getprocs (proclist)");
+		glibtop_error_io_r (server, "kvm_getprocs (%d)", pid);
 
 	/* Now we get the memory maps. */
 
@@ -130,8 +137,13 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 			update = 1;
 		}
 
+#ifdef __FreeBSD__
 		if (entry.eflags & (MAP_ENTRY_IS_A_MAP|MAP_ENTRY_IS_SUB_MAP))
 			continue;
+#else
+		if (entry.is_a_map || entry.is_sub_map)
+			continue;
+#endif
 
 		maps [i].flags  = _glibtop_sysdeps_map_entry;
 
@@ -160,6 +172,7 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 			      &object, sizeof (object)) != sizeof (object))
 			glibtop_error_io_r (server, "kvm_read (object)");
 
+#ifdef __FreeBSD__
 		/* If the object is of type vnode, add its size */
 
 		if (object.type != OBJT_VNODE)
@@ -188,7 +201,7 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 
 		maps [i-1].inode  = inode.i_number;
 		maps [i-1].device = inode.i_dev;
-
+#endif
 	} while (entry.next != first);
 
 	return maps;
