@@ -1,4 +1,4 @@
-/* $Id: procmem.c,v 1.9 1998/08/24 19:55:29 martin Exp $ */
+/* $Id: procmem.c,v 1.14 1998/12/06 11:08:11 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -37,7 +37,9 @@
 #include <ufs/ufs/inode.h>
 
 #include <sys/ucred.h>
+#ifndef __OpenBSD__
 #include <sys/user.h>
+#endif
 #include <sys/sysctl.h>
 #include <vm/vm.h>
 
@@ -66,8 +68,6 @@ glibtop_init_proc_mem_p (glibtop *server)
 {
 	register int pagesize;
 
-	server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem;
-
 	/* get the page size with "getpagesize" and calculate pageshift
 	 * from it */
 	pagesize = getpagesize ();
@@ -79,6 +79,8 @@ glibtop_init_proc_mem_p (glibtop *server)
 
 	/* we only need the amount of log(2)1024 for our conversion */
 	pageshift -= LOG1024;
+
+	server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem;
 }
 
 /* Provides detailed information about a process. */
@@ -88,30 +90,35 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 			pid_t pid)
 {
 	struct kinfo_proc *pinfo;
-	struct user *u_addr = (struct user *)USRSTACK;
 	struct vm_map_entry entry, *first;
 	struct vmspace *vms, vmspace;
 	struct vm_object object;
 	struct plimit plimit;
-	struct vnode vnode;
-	struct inode inode;
 	int count;
 
 	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_MEM), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_mem));
 
-	glibtop_suid_enter (server);
+	if (server->sysdeps.proc_mem == 0)
+		return;
 
+	/* It does not work for the swapper task. */
+	if (pid == 0) return;
+	
 	/* Get the process data */
 	pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, &count);
-	if ((pinfo == NULL) || (count < 1))
-		glibtop_error_io_r (server, "kvm_getprocs (proclist)");
+	if ((pinfo == NULL) || (count < 1)) {
+		glibtop_warn_io_r (server, "kvm_getprocs (%d)", pid);
+		return;
+	}
 
 	if (kvm_read (server->machine.kd,
 		      (unsigned long) pinfo [0].kp_proc.p_limit,
-		      (char *) &plimit, sizeof (plimit)) != sizeof (plimit))
-		glibtop_error_io_r (server, "kvm_read (plimit)");
+		      (char *) &plimit, sizeof (plimit)) != sizeof (plimit)) {
+		glibtop_warn_io_r (server, "kvm_read (plimit)");
+		return;
+	}
 
 	buf->rss_rlim = (u_int64_t) 
 		(plimit.pl_rlimit [RLIMIT_RSS].rlim_cur);
@@ -128,15 +135,19 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 
 	if (kvm_read (server->machine.kd,
 		      (unsigned long) pinfo [0].kp_proc.p_vmspace,
-		      (char *) &vmspace, sizeof (vmspace)) != sizeof (vmspace))
-		glibtop_error_io_r (server, "kvm_read (vmspace)");
+		      (char *) &vmspace, sizeof (vmspace)) != sizeof (vmspace)) {
+		glibtop_warn_io_r (server, "kvm_read (vmspace)");
+		return;
+	}
 
 	first = vmspace.vm_map.header.next;
 
 	if (kvm_read (server->machine.kd,
 		      (unsigned long) vmspace.vm_map.header.next,
-		      (char *) &entry, sizeof (entry)) != sizeof (entry))
-		glibtop_error_io_r (server, "kvm_read (entry)");
+		      (char *) &entry, sizeof (entry)) != sizeof (entry)) {
+		glibtop_warn_io_r (server, "kvm_read (entry)");
+		return;
+	}
 
 	/* Walk through the `vm_map_entry' list ... */
 
@@ -147,11 +158,18 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 	while (entry.next != first) {
 		if (kvm_read (server->machine.kd,
 			      (unsigned long) entry.next,
-			      &entry, sizeof (entry)) != sizeof (entry))
-			glibtop_error_io_r (server, "kvm_read (entry)");
+			      &entry, sizeof (entry)) != sizeof (entry)) {
+			glibtop_warn_io_r (server, "kvm_read (entry)");
+			return;
+		}
 
+#ifdef __FreeBSD__
 		if (entry.eflags & (MAP_ENTRY_IS_A_MAP|MAP_ENTRY_IS_SUB_MAP))
 			continue;
+#else
+		if (entry.is_a_map || entry.is_sub_map)
+			continue;
+#endif
 
 		if (!entry.object.vm_object)
 			continue;
@@ -160,18 +178,22 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 
 		if (kvm_read (server->machine.kd,
 			      (unsigned long) entry.object.vm_object,
-			      &object, sizeof (object)) != sizeof (object))
-			glibtop_error_io_r (server, "kvm_read (object)");
+			      &object, sizeof (object)) != sizeof (object)) {
+			glibtop_warn_io_r (server, "kvm_read (object)");
+			return;
+		}
 
 		/* If the object is of type vnode, add its size */
 
+#ifdef __FreeBSD__
 		if (object.type != OBJT_VNODE)
 			continue;
 
 		buf->share += object.un_pager.vnp.vnp_size;
+#else
+		buf->share += object.size;
+#endif
 	}
 
-	glibtop_suid_leave (server);
-
 	buf->flags = _glibtop_sysdeps_proc_mem;
 }
