@@ -1,4 +1,4 @@
-/* $Id: shm_limits.c,v 1.4 1998/08/24 19:55:36 martin Exp $ */
+/* $Id: shm_limits.c,v 1.6 1998/12/05 18:52:08 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -27,7 +27,11 @@
 
 /* #define KERNEL to get declaration of `struct shminfo'. */
 
-#define KERNEL
+#ifdef __FreeBSD__
+#define KERNEL 1
+#else
+#define _KERNEL 1
+#endif
 
 #include <sys/ipc.h>
 #include <sys/shm.h>
@@ -53,14 +57,18 @@ static struct nlist nlst [] = {
 void
 glibtop_init_shm_limits_p (glibtop *server)
 {
-	server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
-
-	if (kvm_nlist (server->machine.kd, nlst) != 0)
-		glibtop_error_io_r (server, "kvm_nlist");
+	if (kvm_nlist (server->machine.kd, nlst) != 0) {
+		glibtop_warn_io_r (server, "kvm_nlist (shm_limits)");
+		return;
+	}
 	
 	if (kvm_read (server->machine.kd, nlst [0].n_value,
-		      &_shminfo, sizeof (_shminfo)) != sizeof (_shminfo))
-		glibtop_error_io_r (server, "kvm_read (shminfo)");
+		      &_shminfo, sizeof (_shminfo)) != sizeof (_shminfo)) {
+		glibtop_warn_io_r (server, "kvm_read (shminfo)");
+		return;
+	}
+
+	server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
 }
 
 /* Provides information about sysv ipc limits. */
@@ -72,6 +80,9 @@ glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 	
 	memset (buf, 0, sizeof (glibtop_shm_limits));
 
+	if (server->sysdeps.shm_limits == 0)
+		return;
+
 	buf->shmmax = _shminfo.shmmax;
 	buf->shmmin = _shminfo.shmmin;
 	buf->shmmni = _shminfo.shmmni;
