@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: open.c,v 1.10 1998/10/06 09:04:26 martin Exp $ */
 
 /* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    This file is part of the Gnome Top Library.
@@ -56,7 +56,8 @@ static void set_linux_version(void) {
 
 void
 glibtop_open_s (glibtop *server, const char *program_name,
-		const unsigned long features, const unsigned flags)
+		const unsigned long features,
+		const unsigned flags)
 {
 #ifdef HAVE_LIBGTOP_SMP
 	char buffer [BUFSIZ], *p;
